@@ -18,5 +18,5 @@ from .store import Store  # noqa: F401
 from .store_engine import StoreEngine  # noqa: F401
 from .store_file import FileStoreEngine  # noqa: F401
 from .store_object import StoreObject  # noqa: F401
-from .store_vault import VaultRESTClient  # noqa: F401
+from .store_vault import VaultClient  # noqa: F401
 from .store_vault import VaultStoreEngine  # noqa: F401
